@@ -4,6 +4,7 @@ use std::{
     future::Future,
     io::Error,
     pin::Pin,
+    str::FromStr,
     task::{Context, Poll},
 };
 
@@ -517,6 +518,21 @@ impl RequestBuilder {
         Self { uri, ..self }
     }
 
+    /// Sets the URI string for this request.
+    ///
+    /// By default this is `/`.
+    ///
+    /// # Panics
+    ///
+    /// Panic when uri is invalid.
+    #[must_use]
+    pub fn uri_str(self, uri: impl AsRef<str>) -> RequestBuilder {
+        Self {
+            uri: Uri::from_str(uri.as_ref()).expect("valid url"),
+            ..self
+        }
+    }
+
     /// Sets the HTTP version for this request.
     #[must_use]
     pub fn version(self, version: Version) -> RequestBuilder {
